@@ -1,4 +1,4 @@
-from Pillow import ImageFont
+from PIL import ImageFont
 from barcode.writer import mm2px, ImageWriter, FONT
 
 
